/**
 * Component map for storing entity ids and related component data
 * @category Maps
 */
export declare class ComponentMap<TComponentInstance> extends Map<number, TComponentInstance> {
    /**
     * Returns the first entity entry
     */
    firstEntry(): [entityId: number, value: TComponentInstance] | undefined;
    /**
     * Returns the first entity id
     */
    firstKey(): number | undefined;
    /**
     * Returns the first entity value
     */
    firstValue(): TComponentInstance | undefined;
    /**
     * Called when using JSON.stringify
     */
    toJSON(): {
        ComponentMap: number;
        iterable: [number, TComponentInstance][];
    };
    toTable(excludeKeys?: boolean): any[];
    /**
     * Prints entity data in a tabular format to the console
     */
    printTable(excludeKeys?: boolean): void;
    static get [Symbol.species](): MapConstructor;
}
/**
 * Component class map for storing registered component maps
 * @category Maps
 */
export declare class ComponentClassesMap extends Map<string, ComponentMap<any>> {
    /**
     * Called when using JSON.stringify
     */
    toJSON(): {
        ComponentClassesMap: number;
        iterable: [string, ComponentMap<any>][];
    };
    static get [Symbol.species](): MapConstructor;
}
//# sourceMappingURL=component-map.d.ts.map